#include <QtGui/QFileDialog>
#include <QtGui/QMessageBox>

#include "QMyWindow.h"

QMyWindow::QMyWindow(QWidget *parent): QMainWindow(parent) 
{
	m_ui.setupUi(this);

	connect( m_ui.actionLoad_Image, SIGNAL(triggered()), SLOT(slotLoadImage()));
	connect( this, SIGNAL(signalLoadImage(const QImage &)), m_ui.originalImageWidget, SLOT(slotSetImage(const QImage &)));
	connect( this, SIGNAL(signalLoadImage(const QImage &)), m_ui.rgbEqualizedWidget, SLOT(slotSetImage(const QImage &)));
	connect( this, SIGNAL(signalLoadImage(const QImage &)), m_ui.hsvEqualizedWidget, SLOT(slotSetImage(const QImage &)));

	connect( m_ui.redCheckBox,   SIGNAL(toggled(bool)), m_ui.rgbEqualizedWidget, SLOT(slotEqualizeChannel1(bool)) );
	connect( m_ui.greenCheckBox, SIGNAL(toggled(bool)), m_ui.rgbEqualizedWidget, SLOT(slotEqualizeChannel2(bool)) );
	connect( m_ui.blueCheckBox,  SIGNAL(toggled(bool)), m_ui.rgbEqualizedWidget, SLOT(slotEqualizeChannel3(bool)) );

	connect( m_ui.hueCheckBox,        SIGNAL(toggled(bool)), m_ui.hsvEqualizedWidget, SLOT(slotEqualizeChannel1(bool)) );
	connect( m_ui.saturationCheckBox, SIGNAL(toggled(bool)), m_ui.hsvEqualizedWidget, SLOT(slotEqualizeChannel2(bool)) );
	connect( m_ui.valueCheckBox,      SIGNAL(toggled(bool)), m_ui.hsvEqualizedWidget, SLOT(slotEqualizeChannel3(bool)) );

	connect( m_ui.originalImageWidget, SIGNAL(changeHistogram(const int * const * ,int)), m_ui.histogramWidget, SLOT(slotSetHistogram(const int * const * ,int)) );
	connect( m_ui.rgbEqualizedWidget, SIGNAL(changeHistogram(const int * const * ,int)), m_ui.histogramWidget, SLOT(slotSetHistogram(const int * const * ,int)) );
	connect( m_ui.hsvEqualizedWidget, SIGNAL(changeHistogram(const int * const * ,int)), m_ui.histogramWidget, SLOT(slotSetHistogram(const int * const * ,int)) );

	connect( m_ui.actionExit, SIGNAL(triggered()), SLOT(slotQuitApp()));
}  

void QMyWindow::init()
{
	m_ui.rgbEqualizedWidget->setColorSpace(PictureArea::RGB);
	m_ui.rgbEqualizedWidget->setColorSpace(PictureArea::HSV);

	m_ui.redCheckBox->setChecked(false);
	m_ui.greenCheckBox->setChecked(false);
	m_ui.blueCheckBox->setChecked(false);

	m_ui.hueCheckBox->setChecked(false);
	m_ui.saturationCheckBox->setChecked(false);
	m_ui.valueCheckBox->setChecked(false);
}

void QMyWindow::slotQuitApp() 
{ 
	emit signalQuitApp(); 
}

void QMyWindow::slotLoadImage() 
{ 
	QString fileName = QFileDialog::getOpenFileName(this,"Load Image","./","Image Files (*.png *.jpg *.bmp)");
	if(!fileName.isNull())
	{
		QImage image;
		if ( !image.load(fileName) ) 
		{
			QMessageBox::warning(this, tr("Open Image"), tr("The image file could not be loaded."),	QMessageBox::Cancel, QMessageBox::NoButton);
		}
		else
		{
			emit signalLoadImage(image);
		}
	}
}

