
/**  Little program for color transfer
*
* @author
*   Gabriel Zachmann, Sep 2006
*
* @bug
*   I'm sure there is still some bugs left ....
**/

#ifndef PICTUREAREA_H
#define PICTUREAREA_H

#include <QtGui/QImage>
#include <QtGui/QWidget>
#include <QtGui/QPainter>

class PictureArea : public QWidget
{
    Q_OBJECT
	static const unsigned int NUM_BINS = 256;

public:
	enum ColorSpace { RGB, HSV };

	static void RGB2HSV(float r, float g, float b, float *h, float *s, float *v);
	static void HSV2RGB(float h, float s, float v, float *r, float *g, float *b);

    PictureArea(QWidget *parent = 0);
	~PictureArea();

	void setColorSpace(ColorSpace cs) { m_colorSpace = cs; }

public slots:
	void slotSetImage(const QImage &image);
	void slotEqualizeChannel1(bool enable) { slotEqualizeChannel(0,enable); }
	void slotEqualizeChannel2(bool enable) { slotEqualizeChannel(1,enable); }
	void slotEqualizeChannel3(bool enable) { slotEqualizeChannel(2,enable); }

signals:
    void changeHistogram(const int * const *histo, int numBins);
	
protected:
	virtual void mousePressEvent( QMouseEvent *event );
    void paintEvent(QPaintEvent *event);
	void slotEqualizeChannel(int c, bool enable)  { m_equalize_chan[c] = enable; equalizeImage(*m_originalImage,*m_eqalizedImage); update(); }

	void resetHistogram(int channel);						//!< set all entries in m_Histo to 0
	void setHistogram2Identity(int channel);
	void computeHistogram(const QImage &imageIn);
	void equalizeImage(const QImage &image, QImage &imageOut);

private:
    QImage			*m_originalImage;					//!< final image after histogram equalization
	QImage			*m_eqalizedImage;
	ColorSpace		m_colorSpace;						//!< color space, in that hist equaliz. is applied
	bool			m_equalize_chan[3];					//!< apply histogram equalization to channel 3
	
	int				**m_Histo;							//!< histograms for all three channels
};

#endif // PICTUREAREA_H
